# PyEzEmail

_Libreria para facilitar el envio de mails_

### Pre-requisitos 📋

_Ninguno_

### Instalación 🔧

```
pip install PyEzEmail
```

## Autores ✒️

* **Pedro Lamarca** - *Trabajo Inicial* - [shinraxor](https://github.com/shinraxor)
